@@ -32,7 +32,7 @@ use Locale::Maketext::Simple    Class => 'CPANPLUS', Style => 'gettext';
 
 local $Params::Check::VERBOSE = 1;
 
-$VERSION = '0.74';
+$VERSION = '0.82';
 
 =pod
 
@@ -274,6 +274,10 @@ sub prepare {
     my $fail; my $prereq_fail;
     my $status = { };
     RUN: {
+
+        local $ENV{PERL_USE_UNSAFE_INC} = 1
+          unless exists $ENV{PERL_USE_UNSAFE_INC};
+
         # 0.85_01
         ### we resolve 'configure requires' here, so we can run the 'perl
         ### Makefile.PL' command
@@ -350,7 +354,9 @@ sub prepare {
     }
 
     ### send out test report? ###
-    if( $fail and $conf->get_conf('cpantest') and not $prereq_fail ) {
+    ### there is no way to accurately know if it is a PASS/FAIL/ETC
+    ### CPANPLUS::Dist::MM doesn't bother why are we?
+    if( 0 and $fail and $conf->get_conf('cpantest') and not $prereq_fail ) {
            $cb->_send_report(
             module  => $self,
             failed  => $fail,
@@ -439,7 +445,7 @@ sub _find_prereqs {
       return unless $content;
       my $bphash = eval $content;
       return unless $bphash and ref $bphash eq 'HASH';
-      foreach my $type ('requires', 'build_requires') {
+      foreach my $type ('requires', 'build_requires', 'test_requires') {
         next unless $bphash->{$type} and ref $bphash->{$type} eq 'HASH';
         $prereqs->{$_} = $bphash->{$type}->{$_} for keys %{ $bphash->{$type} };
       }
@@ -588,6 +594,9 @@ sub create {
     my $status = { };
     RUN: {
 
+        local $ENV{PERL_USE_UNSAFE_INC} = 1
+          unless exists $ENV{PERL_USE_UNSAFE_INC};
+
         my @run_perl    = ( '-e', CPDB_PERL_WRAPPER );
 
         ### this will set the directory back to the start
@@ -654,6 +663,7 @@ sub create {
             else {
                 $cmd     = [$perl, @run_perl, BUILD->($dir), "test", @buildflags];
             }
+            local $ENV{PERL_INSTALL_QUIET};
             unless ( scalar run(    command => $cmd,
                                     buffer  => \$test_output,
                                     verbose => $verbose )
@@ -776,6 +786,9 @@ sub install {
     my @buildflags = $dist->_buildflags_as_list( $buildflags );
     my @run_perl    = ( '-e', CPDB_PERL_WRAPPER );
 
+    local $ENV{PERL_USE_UNSAFE_INC} = 1
+      unless exists $ENV{PERL_USE_UNSAFE_INC};
+
     ### hmm, how is this going to deal with sudo?
     ### for now, check effective uid, if it's not root,
     ### shell out, otherwise use the method
